=====================
Django3 Registration
=====================

This is an extensible user-registration application for Django.  It
was forked of the "2.x" branch of `this project
<https://github.com/ubernostrum/django-registration/>`_.

That project completely changed its approach to registrations in version
3.0.  It eliminated models entirely and made many other big changes.
Converting an existing 2.x project to 3.0 was proving to be
prohibitively time consuming, so this fork was created to allow the
older approach to work under Python 3 and newer versions of Django.

Full documentation is `available online
<https://django-registration.readthedocs.io/>`_.

Installation
============
    $ pip install django3-registration
